@@ -390,10 +390,7 @@ class Alpaca(Broker):
                 asset_type=Asset.AssetType.CRYPTO,
             )
         elif position.asset_class == "option":
-            asset = Asset(
-                symbol=position.symbol,
-                asset_type=Asset.AssetType.OPTION,
-            )
+            asset = Asset.symbol2asset(position.symbol)
         else:
             asset = Asset(
                 symbol=position.symbol,
