@@ -16,7 +16,7 @@ from lumibot.entities import Asset, Order, Position
 from lumibot.tools.lumibot_logger import get_logger
 from lumibot.tools.projectx_helpers import ProjectXClient
 from termcolor import colored
-from lumibot.trading_builtins.custom_stream import PollingStream
+# PollingStream usage was removed to align with centralized lifecycle in core Broker
 import traceback
 
 # Import moved to avoid circular dependency
@@ -134,7 +134,7 @@ class ProjectX(Broker):
         self.connect_stream = connect_stream
         self.streaming_client = None
 
-        # Order tracking
+        # Order/position caches
         self._orders_cache = {}  # Store orders by their IDs
         self._positions_cache = {}  # Store positions
 
@@ -155,24 +155,6 @@ class ProjectX(Broker):
         self.logger.debug(f"ProjectX broker initialized for {self.firm}")
         self.logger.debug(f"Data source: {data_source.__class__.__name__ if data_source else 'None'}")
         self.logger.debug(f"Streaming enabled: {connect_stream}")
-        # Polling (fallback and supplemental) for order/position lifecycle when streaming absent or incomplete
-        try:
-            import os
-            self.polling_interval = float(os.environ.get("PROJECTX_POLLING_INTERVAL", "5"))
-            from lumibot.trading_builtins.custom_stream import PollingStream as _PXPolling
-            self._polling_stream = _PXPolling(polling_interval=self.polling_interval)
-            self._register_polling_actions()
-            # Use the polling stream as the broker's primary stream (so dispatches produce standard lifecycle logs)
-            self.stream = self._polling_stream
-            # Register event handlers (NEW/FILLED/CANCELED/ERROR) on this stream
-            try:
-                self._register_stream_events()
-            except Exception as _evt_exc:
-                self.logger.debug(f"Stream events registration failed (non-fatal): {_evt_exc}")
-            import threading as _threading
-            _threading.Thread(target=self._polling_stream.run, args=(f"ProjectXPolling-{self.firm}",), daemon=True).start()
-        except Exception as poll_e:
-            self.logger.debug(f"Polling init failed (non-fatal): {poll_e}")
 
         # Check if we should auto-connect
         if not self.account_id:
@@ -198,8 +180,7 @@ class ProjectX(Broker):
                 self.logger.debug("Setting up streaming connection")
                 self._setup_streaming()
 
-            # Sync existing orders into tracking system for strategy compatibility
-            self._sync_existing_orders_to_tracking()
+            # No adapter-level sync; rely on core Broker's first-iteration handling
 
             self.logger.debug("ProjectX broker connection complete")
             return True
@@ -257,15 +238,11 @@ class ProjectX(Broker):
             if success:
                 # Update order status
                 order.status = "cancelled"
-                # Apply tracking transition so strategy sees cancellation immediately
-                try:
-                    # Ensure identifier present
-                    if not getattr(order, "identifier", None):
-                        order.identifier = order.id
-                    self._apply_order_update_tracking(order)
-                except Exception as track_exc:
-                    self.logger.debug(f"Cancel tracking application failed for {order.id}: {track_exc}")
-                self.logger.info(f"Order {order.id} cancelled successfully")
+                # Ensure identifier present; lifecycle routing handled centrally
+                if not getattr(order, "identifier", None):
+                    order.identifier = order.id
+                # Downgrade adapter-level logs; centralized system handles lifecycle
+                self.logger.debug(f"Order {order.id} cancelled successfully")
                 return True
             else:
                 error_msg = None
@@ -314,7 +291,8 @@ class ProjectX(Broker):
                 if stop_price is not None:
                     order.stop_price = stop_price
 
-                self.logger.info(f"Order {order.id} modified successfully")
+                # Adapter should not emit high-level lifecycle logs
+                self.logger.debug(f"Order {order.id} modified successfully")
                 return True
             else:
                 error_msg = response.get("errorMessage", "Unknown error") if response else "No response"
@@ -407,49 +385,11 @@ class ProjectX(Broker):
                 order.limit_price = limit_price
                 order.stop_price = stop_price
 
-                # Cache the order
+                # Cache the order for quick lookups; lifecycle handled centrally
                 self._orders_cache[order.id] = order
-                # Ensure strategy name is set for tracking if available
-                if hasattr(order, 'strategy') and order.strategy:
-                    strategy_name = order.strategy if isinstance(order.strategy, str) else getattr(order.strategy, 'name', '')
-                else:
-                    strategy_name = ''
-                # Insert into broker tracking lists so subsequent get_orders() shows it
-                try:
-                    self._process_new_order(order)
-                except Exception as track_exc:
-                    self.logger.debug(f"Failed to process new order into tracking: {track_exc}")
-
-                # Set broker-reported status AFTER _process_new_order (which may set 'new')
-                try:
-                    order.status = "submitted"
-                    # Apply lifecycle tracking to emit green transition log
-                    self._apply_order_update_tracking(order)
-                except Exception as lifecycle_e:
-                    self.logger.debug(f"Post submit lifecycle sync failed: {lifecycle_e}")
-
-                self.logger.info(f"Order submitted successfully with ID: {order.id}")
-                try:
-                    # Use WARNING level so test harness (which captures WARNING+ by default) records lifecycle events
-                    self.logger.warning(f"[ProjectX] Order SUBMITTED {order}")
-                except Exception:
-                    pass
-                # Trigger an immediate polling cycle so status logs appear quickly
-                try:
-                    from lumibot.trading_builtins.custom_stream import PollingStream as _PS
-                    if getattr(self, '_polling_stream', None):
-                        self._polling_stream.dispatch(_PS.POLL_EVENT)
-                except Exception:
-                    pass
-                # Dispatch NEW_ORDER event to mimic other brokers' immediate green log behavior
-                try:
-                    if hasattr(self, 'stream') and self.stream:
-                        # Ensure tracking list has order
-                        if order not in self._new_orders:
-                            self._process_new_order(order)
-                        self.stream.dispatch(self.NEW_ORDER, order=order)
-                except Exception as _dispatch_exc:
-                    self.logger.debug(f"ProjectX NEW_ORDER dispatch failed: {_dispatch_exc}")
+                order.status = "submitted"
+                # Adapter-level success logging reduced to debug; lifecycle logs are centralized
+                self.logger.debug(f"Order submitted successfully with ID: {order.id}")
             else:
                 error_msg = response.get("errorMessage", "Unknown error") if response else "No response"
                 # Map specific broker error codes/messages to standardized handling
@@ -465,6 +405,7 @@ class ProjectX(Broker):
                 else:
                     order.status = "rejected"
                     order.error = error_msg
+                    # Keep error log for submit failures
                     self.logger.error(f"Failed to submit order: {error_msg}")
 
             return order
@@ -472,6 +413,7 @@ class ProjectX(Broker):
         except Exception as e:
             order.status = "rejected"
             order.error = str(e)
+            # Keep error log for visibility
             self.logger.error(f"Error submitting order: {e}")
             return order
 
@@ -546,6 +488,10 @@ class ProjectX(Broker):
             for broker_order in orders_data[:50]:
                 conversion_attempts += 1
                 try:
+                    # Guard against unexpected payload shapes (e.g., list)
+                    if not isinstance(broker_order, dict):
+                        self.logger.debug(f"Skipping non-dict order payload: {type(broker_order)}")
+                        continue
                     order_id = broker_order.get('id', 'unknown')
                     status = broker_order.get('status', 'unknown')
                     order_type = broker_order.get('type', 'unknown')
@@ -561,7 +507,9 @@ class ProjectX(Broker):
                         self.logger.debug(f"❌ Order {order_id} conversion returned None")
 
                 except Exception as e:
-                    self.logger.error(f"❌ Failed to convert order {broker_order.get('id', 'unknown')}: {e}")
+                    # Guard against non-dict in error path
+                    order_id = broker_order.get('id', 'unknown') if isinstance(broker_order, dict) else 'unknown'
+                    self.logger.error(f"❌ Failed to convert order {order_id}: {e}")
                     import traceback
                     self.logger.error(f"Full traceback: {traceback.format_exc()}")
                     continue
@@ -595,16 +543,20 @@ class ProjectX(Broker):
 
             for broker_position in positions_data:
                 try:
+                    if not isinstance(broker_position, dict):
+                        self.logger.debug(f"Skipping non-dict position payload: {type(broker_position)}")
+                        continue
                     position = self._convert_broker_position_to_lumibot_position(broker_position)
                     if position is not None:
                         positions.append(position)
                         # Update cache
                         self._positions_cache[position.asset.symbol] = position
                     else:
-                        contract_id = broker_position.get('contractId', 'unknown')
-                        self.logger.warning(f"❌ Position {contract_id} conversion returned None")
+                        contract_id = broker_position.get('contractId', 'unknown') if isinstance(broker_position, dict) else 'unknown'
+                        self.logger.debug(f"Position {contract_id} conversion returned None")
                 except Exception as e:
-                    self.logger.error(f"❌ Failed to convert position {broker_position.get('contractId', 'unknown')}: {e}")
+                    contract_id = broker_position.get('contractId', 'unknown') if isinstance(broker_position, dict) else 'unknown'
+                    self.logger.error(f"❌ Failed to convert position {contract_id}: {e}")
                     continue
 
             # Final safety check - filter out any None positions
@@ -645,38 +597,8 @@ class ProjectX(Broker):
         return self.streaming_client
 
     def _register_stream_events(self):
-        """Register stream lifecycle event handlers (mirrors behavior of other brokers)."""
-        broker = self
-        if not hasattr(self, 'stream') or self.stream is None:
-            return
-
-        @broker.stream.add_action(broker.NEW_ORDER)
-        def _on_new(order):
-            try:
-                broker.logger.info(colored(f"[ProjectX] Processing NEW order {order}", "green"))
-            except Exception:
-                broker.logger.debug(traceback.format_exc())
-
-        @broker.stream.add_action(broker.FILLED_ORDER)
-        def _on_filled(order, price, filled_quantity):
-            try:
-                broker.logger.info(colored(f"[ProjectX] Processing FILLED order {filled_quantity} @ {price} {order}", "green"))
-            except Exception:
-                broker.logger.debug(traceback.format_exc())
-
-        @broker.stream.add_action(broker.CANCELED_ORDER)
-        def _on_canceled(order):
-            try:
-                broker.logger.info(colored(f"[ProjectX] Processing CANCELED order {order}", "yellow"))
-            except Exception:
-                broker.logger.debug(traceback.format_exc())
-
-        @broker.stream.add_action(broker.ERROR_ORDER)
-        def _on_error(order, error_msg=None):
-            try:
-                broker.logger.error(colored(f"[ProjectX] Processing ERROR order {order} | {error_msg}", "red"))
-            except Exception:
-                broker.logger.debug(traceback.format_exc())
+        """No-op: adapter doesn't emit lifecycle; core Broker manages routing."""
+        return
 
     def _run_stream(self):
         """Run the stream."""
@@ -725,7 +647,7 @@ class ProjectX(Broker):
             # order_search returns a list directly, not a dict with orders key
             if isinstance(orders, list):
                 return orders
-            elif isinstance(orders, dict) and orders.get("success"):
+            if isinstance(orders, dict) and orders.get("success"):
                 return orders.get("orders", [])
 
             return []
@@ -734,8 +656,6 @@ class ProjectX(Broker):
             self.logger.error(f"Error getting all orders: {e}")
             return []
 
-    # ========== Helper Methods ==========
-
     def _get_contract_id_from_asset(self, asset: Asset) -> str:
         """Get ProjectX contract ID from Lumibot asset."""
         try:
@@ -790,6 +710,9 @@ class ProjectX(Broker):
     def _convert_broker_order_to_lumibot_order(self, broker_order: dict) -> Order:
         """Convert ProjectX order to Lumibot Order object."""
         try:
+            # Ignore unexpected payloads
+            if not isinstance(broker_order, dict):
+                return None
             # Get asset from contract - use efficient lookup
             contract_id = broker_order.get("contractId")
             asset = self._get_asset_from_contract_id_cached(contract_id)
@@ -811,7 +734,8 @@ class ProjectX(Broker):
             status = self.ORDER_STATUS_MAPPING.get(status_id, f"unknown_status_{status_id}")
 
             if status.startswith("unknown_status_"):
-                self.logger.warning(f"Unknown order status ID: {status_id} for order {broker_order.get('id')}")
+                # Downgrade to debug to avoid adapter-level noise
+                self.logger.debug(f"Unknown order status ID: {status_id} for order {broker_order.get('id')}")
 
             # Create Order object
             order = Order(
@@ -847,212 +771,19 @@ class ProjectX(Broker):
             return order
 
         except Exception as e:
+            # Keep error log; avoid crashing conversion loop
             self.logger.error(f"Error converting broker order: {e}")
             return None
 
     # ================= Lifecycle Processing Helpers ==================
-    def _register_polling_actions(self):
-        """Register periodic polling callbacks for orders & positions."""
-        @self._polling_stream.add_action(PollingStream.POLL_EVENT)
-        def _poll():
-            try:
-                if not self.account_id:
-                    # Attempt lazy connect (will no-op if fails)
-                    self.connect()
-                if not self.account_id:
-                    return
-                # Fetch latest orders
-                orders = self._get_orders_at_broker()
-                tracked_prior = {o.identifier: o for o in self.get_tracked_orders()}
-                for o in orders:
-                    try:
-                        prev = tracked_prior.get(getattr(o, 'identifier', getattr(o, 'id', None)))
-                        prev_status = getattr(prev, 'status', None) if prev else None
-                        self._apply_order_update_tracking(o)
-                        if hasattr(self, 'stream') and self.stream:
-                            new_status = (o.status or '').lower()
-                            if prev is None and new_status in ('new','submitted','open'):
-                                self.stream.dispatch(self.NEW_ORDER, order=o)
-                            elif prev_status and prev_status != o.status:
-                                if new_status in ('fill','filled'):
-                                    price = getattr(o, 'avg_fill_price', None) or getattr(o, 'limit_price', None) or 0
-                                    qty = getattr(o, 'filled_quantity', None) or getattr(o, 'quantity', None) or 0
-                                    if price is not None and qty is not None:
-                                        self.stream.dispatch(self.FILLED_ORDER, order=o, price=price, filled_quantity=qty)
-                                elif new_status in ('canceled','cancelled','expired'):
-                                    self.stream.dispatch(self.CANCELED_ORDER, order=o)
-                                elif new_status in ('error','rejected'):
-                                    self.stream.dispatch(self.ERROR_ORDER, order=o, error_msg=getattr(o, 'error', 'Broker error'))
-                    except Exception as oe:
-                        self.logger.debug(f"Polling order tracking failed: {oe}")
-                # Fetch positions
-                try:
-                    positions = self._get_positions_at_broker()
-                    for p in positions:
-                        if not p:
-                            continue
-                        # Assign strategy if missing
-                        if not getattr(p, 'strategy', None) and self._subscribers:
-                            p.strategy = self._subscribers[0].name
-                        # Track filled positions list if not already present
-                        existing = self.get_tracked_position(p.strategy, p.asset) if getattr(p, 'strategy', None) else None
-                        if not existing and getattr(p, 'strategy', None) and p.quantity != 0:
-                            self._filled_positions.append(p)
-
-                    # === Fast-fill reconciliation ===
-                    # If a market order was submitted/open but broker hasn't yet reported fill status,
-                    # infer fill ONLY (no extra logging) when a position of equal/greater size appears.
-                    try:
-                        pos_map = {p.asset.symbol: p for p in positions if p and p.quantity != 0}
-                        for o in list(self.get_tracked_orders()):
-                            try:
-                                if getattr(o, 'status', '').lower() in ('new','submitted','open'):
-                                    sym = getattr(o.asset, 'symbol', None)
-                                    if sym and sym in pos_map:
-                                        pos = pos_map[sym]
-                                        # Determine if position change satisfies order quantity
-                                        order_qty = getattr(o, 'quantity', None)
-                                        if order_qty is None:
-                                            continue
-                                        # Simple heuristic: if position qty magnitude >= order qty, treat as filled
-                                        if abs(getattr(pos, 'quantity', 0)) >= abs(order_qty):
-                                            # Avoid double processing
-                                            if getattr(o, 'status','').lower() not in ('filled','fill'):
-                                                fill_price = getattr(o, 'avg_fill_price', None) or getattr(pos, 'avg_fill_price', None) or getattr(o, 'limit_price', None) or 0
-                                                try:
-                                                    self._process_filled_order(o, fill_price, order_qty)
-                                                    o.status = 'filled'
-                                                    # Suppress extra synthetic-specific log line; core processor already logs filled
-                                                    if hasattr(self, 'stream') and self.stream:
-                                                        # Dispatch only if not already dispatched
-                                                        self.stream.dispatch(self.FILLED_ORDER, order=o, price=fill_price, filled_quantity=order_qty)
-                                                except Exception as sf_e:
-                                                    self.logger.debug(f"Fast-fill reconciliation failed: {sf_e}")
-                            except Exception as so_e:
-                                self.logger.debug(f"Synthetic fill loop error: {so_e}")
-                    except Exception as synth_e:
-                        self.logger.debug(f"Synthetic fill detection failed: {synth_e}")
-                except Exception as pe:
-                    self.logger.debug(f"Polling positions failed: {pe}")
-            except Exception as e:
-                self.logger.debug(f"Polling cycle error: {e}")
-
-    def _get_all_tracked_orders(self):
-        """Return a dict of all currently tracked orders keyed by identifier."""
-        tracked = {}
-        for sl in [self._unprocessed_orders, self._placeholder_orders, self._new_orders, self._partially_filled_orders,
-                   self._filled_orders, self._canceled_orders, self._error_orders]:
-            for o in sl.get_list():
-                tracked[getattr(o, "identifier", getattr(o, "id", None))] = o
-        return tracked
-
-    def _apply_order_update_tracking(self, updated_order: Order):
-        """Deterministic lifecycle sync: always routes status changes through Broker processors."""
-        if not updated_order:
-            return
-        ident = getattr(updated_order, "identifier", getattr(updated_order, "id", None))
-        if not ident:
-            return
-        if not getattr(updated_order, "identifier", None):
-            updated_order.identifier = ident
-
-        status_raw = (updated_order.status or "").lower()
-        alias_map = getattr(Order, "STATUS_ALIAS_MAP", {}) if hasattr(Order, "STATUS_ALIAS_MAP") else {}
-        # Normalize common ProjectX partial fill wording
-        # Normalize all broker partial variants to canonical 'partial_fill'
-        if status_raw in ("partially_filled", "partial_filled"):
-            status_raw = "partial_fill"
-        status = alias_map.get(status_raw, status_raw)
-
-        tracked = self._get_all_tracked_orders()
-        obj = tracked.get(ident, updated_order)
-
-        # Assign strategy if missing
-        if not getattr(obj, "strategy", "") and self._subscribers:
-            obj.strategy = self._subscribers[0].name
-
-        # Helper removals
-        def _remove_from_all(o):
-            try: self._new_orders.remove(o.identifier, key="identifier")
-            except Exception: pass
-            try: self._unprocessed_orders.remove(o.identifier, key="identifier")
-            except Exception: pass
-            try: self._partially_filled_orders.remove(o.identifier, key="identifier")
-            except Exception: pass
-
-        try:
-            avg_price = getattr(updated_order, "avg_fill_price", None)
-            if avg_price is None:
-                avg_price = getattr(updated_order, "limit_price", None) or getattr(updated_order, "stop_price", None)
-            filled_qty = getattr(updated_order, "filled_quantity", None)
-
-            if status in ("new", "submitted", "open"):
-                prev_status = getattr(obj, 'status', None)
-                original_status = updated_order.status  # Preserve broker-reported state (submitted/open)
-                # Only call _process_new_order the FIRST time so lists are populated; subsequent polls preserve status
-                if obj not in self._new_orders:
-                    self._process_new_order(obj)
-                # If broker reported something beyond simple 'new', keep it (avoid overwriting with 'new')
-                if original_status and original_status.lower() != 'new':
-                    obj.status = original_status
-                # Log if first time OR status actually advanced
-                if prev_status != obj.status:
-                    transition = f"NEW -> {obj.status.upper()}" if prev_status is None else f"{prev_status.upper()} -> {obj.status.upper()}"
-                    # Promote lifecycle transition visibility to WARNING
-                    try:
-                        self.logger.warning(colored(f"[ProjectX] Order {transition} {obj}", "green"))
-                    except Exception:
-                        self.logger.warning(f"[ProjectX] Order {transition} {obj}")
-            elif status in ("partial_fill", "partially_filled", "partial_filled"):
-                # Ensure order is in tracking collections so subsequent removal doesn't silently fail
-                try:
-                    if obj not in self._new_orders and obj not in self._partially_filled_orders:
-                        # If it was never processed as new (edge test path), process now
-                        self._process_new_order(obj)
-                except Exception:
-                    pass
-                qty = filled_qty if filled_qty not in (None, 0) else getattr(obj, "filled_quantity", None) or 0
-                if qty == 0:
-                    # Assume 1 contract minimum if broker reports partial without quantity (test scenario)
-                    qty = 1
-                if avg_price is None:
-                    avg_price = 0
-                before = obj.filled_quantity if hasattr(obj, 'filled_quantity') else 0
-                self._process_partially_filled_order(obj, avg_price, qty)
-                after = obj.filled_quantity if hasattr(obj, 'filled_quantity') else qty
-                msg = f"[ProjectX] Order PARTIAL {after}/{getattr(obj,'quantity', '?')} @ {avg_price} {obj}"
-                # Plain log first for test capture
-                # Emit plain WARNING (tests capture WARNING+)
-                self.logger.warning(msg)
-                try:
-                    self.logger.warning(colored(msg, "green"))
-                except Exception:
-                    pass
-            elif status in ("fill", "filled"):
-                qty = obj.quantity if getattr(obj, "quantity", None) is not None else (filled_qty or 0)
-                if avg_price is None:
-                    avg_price = 0
-                # Use core filled processor for consistency
-                self._process_filled_order(obj, avg_price, qty)
-                try:
-                    self.logger.warning(colored(f"[ProjectX] Order FILLED {qty} @ {avg_price} {obj}", "green"))
-                except Exception:
-                    self.logger.warning(f"[ProjectX] Order FILLED {qty} @ {avg_price} {obj}")
-            elif status in ("canceled", "cancelled", "expired"):
-                self._process_canceled_order(obj)
-                try:
-                    self.logger.warning(colored(f"[ProjectX] Order CANCELED {obj}", "yellow"))
-                except Exception:
-                    self.logger.warning(f"[ProjectX] Order CANCELED {obj}")
-            elif status in ("error", "rejected"):
-                self._process_error_order(obj, getattr(updated_order, "error", None) or "Broker reported error")
-                self.logger.error(colored(f"[ProjectX] Order ERROR {obj} : {getattr(updated_order,'error', '')}", "red"))
-        except Exception as e:
-            self.logger.error(f"Lifecycle transition failed for {ident}: {e}")
+    # Adapter-level lifecycle routing removed; rely on core Broker's centralized processors
 
     def _convert_broker_position_to_lumibot_position(self, broker_position: dict) -> Position:
         """Convert ProjectX position to Lumibot Position object."""
         try:
+            # Ignore unexpected payloads
+            if not isinstance(broker_position, dict):
+                return None
             # Get asset from contract - use efficient cached lookup
             contract_id = broker_position.get("contractId")
             asset = self._get_asset_from_contract_id_cached(contract_id)
@@ -1079,6 +810,7 @@ class ProjectX(Broker):
             return position
 
         except Exception as e:
+            # Keep error for debugging; no adapter-level lifecycle logs
             self.logger.error(f"Error converting broker position: {e}")
             return None
 
@@ -1197,49 +929,34 @@ class ProjectX(Broker):
     def _handle_order_update(self, data):
         """Handle order update from streaming."""
         try:
-            order = self._convert_broker_order_to_lumibot_order(data)
-            if order is not None:
-                self._orders_cache[order.id] = order
-                prev_orders = {o.identifier: o for o in self.get_tracked_orders()}
-                prev = prev_orders.get(order.identifier)
-                prev_status = getattr(prev, 'status', None) if prev else None
-                self._apply_order_update_tracking(order)
-                # Dispatch events after tracking
-                try:
-                    if hasattr(self, 'stream') and self.stream:
-                        status_lower = (order.status or '').lower()
-                        if prev is None and status_lower in ('new','submitted','open'):
-                            self.stream.dispatch(self.NEW_ORDER, order=order)
-                        elif prev_status and prev_status != order.status:
-                            if status_lower in ('fill','filled'):
-                                price = getattr(order, 'avg_fill_price', None) or getattr(order, 'limit_price', None) or 0
-                                qty = getattr(order, 'filled_quantity', None) or getattr(order, 'quantity', None) or 0
-                                if price is not None and qty is not None:
-                                    self.stream.dispatch(self.FILLED_ORDER, order=order, price=price, filled_quantity=qty)
-                            elif status_lower in ('canceled','cancelled','expired'):
-                                self.stream.dispatch(self.CANCELED_ORDER, order=order)
-                            elif status_lower in ('error','rejected'):
-                                self.stream.dispatch(self.ERROR_ORDER, order=order, error_msg=getattr(order,'error','Broker error'))
-                except Exception as dispatch_e:
-                    self.logger.debug(f"Stream dispatch on order update failed: {dispatch_e}")
-                self.logger.debug(f"Order update processed: {order.id} -> {order.status}")
+            # Stream can deliver a single dict or a list of dicts
+            payloads = data if isinstance(data, list) else [data]
+            for item in payloads:
+                order = self._convert_broker_order_to_lumibot_order(item)
+                if order is not None:
+                    self._orders_cache[order.id] = order
+                    # No adapter-level lifecycle processing; cache update only
+                    self.logger.debug(f"Order update cached: {order.id} -> {order.status}")
         except Exception as e:
             self.logger.error(f"Error handling order update: {e}")
 
     def _handle_position_update(self, data):
         """Handle position update from streaming."""
         try:
-            position = self._convert_broker_position_to_lumibot_position(data)
-            if position is not None:
-                self._positions_cache[position.asset.symbol] = position
-                self.logger.debug(f"Position update received: {position.asset.symbol}")
+            payloads = data if isinstance(data, list) else [data]
+            for item in payloads:
+                position = self._convert_broker_position_to_lumibot_position(item)
+                if position is not None:
+                    self._positions_cache[position.asset.symbol] = position
+                    self.logger.debug(f"Position update received: {position.asset.symbol}")
         except Exception as e:
             self.logger.error(f"Error handling position update: {e}")
 
     def _handle_trade_update(self, data):
         """Handle trade update from streaming."""
         try:
-            self.logger.debug(f"Trade update received: {data}")
+            # Trade updates could be single or batch; log type only to avoid noise
+            self.logger.debug("Trade update received")
             # Trade updates can trigger order and position cache updates
             self._update_orders_cache()
             self._update_positions_cache()
@@ -1249,96 +966,18 @@ class ProjectX(Broker):
     def _handle_account_update(self, data):
         """Handle account update from streaming."""
         try:
-            self.logger.debug(f"Account update received: {data}")
-            self.account_info = data
+            # Account updates may be dict or list; keep last dict seen
+            if isinstance(data, list):
+                for item in data:
+                    if isinstance(item, dict):
+                        self.account_info = item
+            elif isinstance(data, dict):
+                self.account_info = data
+            self.logger.debug("Account update received")
         except Exception as e:
             self.logger.error(f"Error handling account update: {e}")
 
-    def _sync_existing_orders_to_tracking(self):
-        """Sync existing ACTIVE orders from broker into the tracking system for strategy compatibility."""
-        try:
-            self.logger.debug("Syncing active orders into tracking system")
-
-            # CRITICAL: Clear old orders from tracking system to prevent mixing with fresh data
-            # This prevents old canceled orders from previous sessions showing up
-            strategy_name = None
-            if self._subscribers:
-                strategy_name = self._subscribers[0].name
-                self.logger.debug(f"Clearing old orders for strategy: {strategy_name}")
-
-                # Remove old orders for this strategy from all tracking lists
-                old_count = 0
-                for order_list in [self._new_orders, self._partially_filled_orders, self._filled_orders,
-                                 self._canceled_orders, self._error_orders, self._unprocessed_orders]:
-                    orders_to_remove = [order for order in order_list.get_list() if order.strategy == strategy_name]
-                    for order in orders_to_remove:
-                        order_list.remove(order.id, key="id")
-                        old_count += 1
-
-                self.logger.debug(f"Cleared {old_count} old orders from tracking system")
-
-            # Get existing orders from broker
-            all_orders = self._get_orders_at_broker()
-
-            # Filter to only ACTIVE orders to prevent spam from old canceled orders
-            active_orders = [
-                order for order in all_orders
-                if order.status in ["new", "submitted", "open", "partially_filled", "partial_filled"]
-            ]
-
-            self.logger.debug(f"Found {len(active_orders)} active orders to sync (filtered from {len(all_orders)} total)")
-
-            # Only sync if we have active orders - skip if all are canceled/filled
-            if not active_orders:
-                self.logger.debug("No active orders to sync - all orders are completed/canceled")
-                return
-
-            self.logger.debug(f"Assigning active orders to strategy: {strategy_name}")
-
-            synced_count = 0
-            for order in active_orders:
-                try:
-                    # Assign strategy name if available and not already set
-                    if strategy_name:
-                        order.strategy = strategy_name
-                        self.logger.debug(f"Assigned strategy '{strategy_name}' to order {order.id}")
-
-                    # Mark as synced from broker to prevent auto-cancellation during validation
-                    order._synced_from_broker = True
-
-                    # Add orders to appropriate tracking lists based on status
-                    if order.status in ["new", "submitted", "open"]:
-                        self._new_orders.append(order)
-                        synced_count += 1
-                    elif order.status in ["partially_filled", "partial_filled"]:
-                        self._partially_filled_orders.append(order)
-                        synced_count += 1
-
-                except Exception as e:
-                    self.logger.error(f"Failed to sync order {order.id}: {e}")
-                    continue
-
-            self.logger.debug(f"Successfully synced {synced_count} active orders into tracking system")
-
-            # Log summary instead of individual orders
-            if synced_count > 0:
-                status_summary = {}
-                for order in active_orders:
-                    status_summary[order.status] = status_summary.get(order.status, 0) + 1
-                status_text = ", ".join([f"{count} {status}" for status, count in status_summary.items()])
-                self.logger.debug(f"Order status breakdown: {status_text}")
-
-        except Exception as e:
-            self.logger.error(f"❌ Failed to sync existing orders: {e}")
-            # Continue without failing - this is not critical for basic functionality
-
     def _add_subscriber(self, subscriber):
         """Override to sync orders when a strategy is added."""
         super()._add_subscriber(subscriber)
-
-        # Sync existing orders to this strategy
-        try:
-            self.logger.debug(f"Strategy '{subscriber.name}' added - syncing existing orders")
-            self._sync_existing_orders_to_tracking()
-        except Exception as e:
-            self.logger.error(f"Failed to sync orders for new strategy {subscriber.name}: {e}")
+    # No adapter-level sync; core Broker handles first-iteration lifecycle
