@@ -1,10 +1,13 @@
 import json
-import datetime
-import time
-import logging
 import re
+import time
+
 from openai import OpenAI
 
+from lumibot.tools.lumibot_logger import get_logger
+
+logger = get_logger(__name__)
+
 # --- constants ---------------------------------------------------------------
 _MODEL_LIMITS = {
     "sonar": 8000,
@@ -100,7 +103,7 @@ class PerplexityHelper:
       - Financial news queries: Returns structured financial news data.
       - General queries: Returns structured responses based on a provided (or default) JSON schema.
     """
-    
+
     def __init__(self, api_key: str):
         """
         Initializes the PerplexityHelper with your API key and creates an OpenAI-compatible client.
@@ -121,13 +124,13 @@ class PerplexityHelper:
             api_key = os.getenv("PERPLEXITY_API_KEY")
             if not api_key:
                 raise ValueError("API key is required for PerplexityHelper. Set it as PERPLEXITY_API_KEY in your environment or your secrets")
-        
+
         self.api_key = api_key
         self.client = OpenAI(
             api_key=self.api_key,
             base_url="https://api.perplexity.ai",  # Correct base URL
         )
-    
+
     # --------------------------------------------------------------------------
     # Private Helper Methods
     # --------------------------------------------------------------------------
@@ -402,9 +405,9 @@ Return only valid JSON following the schema.
                     response_text = _strip_think_block(response_text)
                 return response_text
             except Exception as e:
-                logging.error(f"Attempt {attempt} failed: {e}")
+                logger.error(f"Attempt {attempt} failed: {e}")
                 if attempt == retries:
-                    logging.error(f"Final attempt failed. System prompt was: {system_msg}")
+                    logger.error(f"Final attempt failed. System prompt was: {system_msg}")
                     raise e
                 time.sleep(1)
         raise RuntimeError("Failed to get a valid response after retries.")
@@ -448,19 +451,19 @@ Return only valid JSON following the schema.
                 "analysis_summary": f"Error calling Perplexity API: {str(e)}",
                 "items": []
             }
-        
+
         # Clean the raw response to remove markdown formatting and extraneous text
         cleaned_text = self._clean_response(assistant_text)
         try:
             data = json.loads(cleaned_text)
         except json.JSONDecodeError as e:
-            logging.error(f"JSON decoding failed. Raw response: {cleaned_text}")
+            logger.error(f"JSON decoding failed. Raw response: {cleaned_text}")
             return {
                 "query": user_query,
                 "analysis_summary": f"Error: LLM output was not valid JSON. {str(e)}",
                 "items": []
             }
-        
+
         self._post_process_data(data)
         return data
 
@@ -618,20 +621,20 @@ Return only valid JSON following the schema.
                 "detailed_response": "",
                 "symbols": []
             }
-        
+
         # Clean the raw response to remove markdown formatting and any extraneous text
         cleaned_text = self._clean_response(assistant_text)
         try:
             data = json.loads(cleaned_text)
         except json.JSONDecodeError as e:
-            logging.error(f"JSON decoding failed. Raw response: {cleaned_text}")
+            logger.error(f"JSON decoding failed. Raw response: {cleaned_text}")
             return {
                 "query": user_query,
                 "response_summary": f"Error: LLM output was not valid JSON. {str(e)}",
                 "detailed_response": "",
                 "symbols": []
             }
-        
+
         return data
 
     # --------------------------------------------------------------------------
@@ -678,6 +681,7 @@ Return only valid JSON following the schema.
 # ------------------------------------------------------------------------------
 if __name__ == "__main__":
     import os
+
     import dotenv
 
     dotenv.load_dotenv()
@@ -715,4 +719,4 @@ if __name__ == "__main__":
     }
     general_result_custom = helper.execute_general_query("Give me a list of current quantum computing stocks with their earnings growth, analyst ratings, and consensus price targets.", custom_schema, model="sonar-pro")
     print("\nGeneral Query Result (Custom Schema):")
-    print(json.dumps(general_result_custom, indent=2))
\ No newline at end of file
+    print(json.dumps(general_result_custom, indent=2))
