@@ -7,12 +7,18 @@ from .exceptions import NoDataFound, UnavailabeTimestep
 from .interactive_brokers_data import InteractiveBrokersData
 from .pandas_data import PandasData
 from .tradier_data import TradierData
-from .yahoo_data import YahooData
-from .ccxt_backtesting_data import CcxtBacktestingData
-from .interactive_brokers_rest_data import InteractiveBrokersRESTData
-from .example_broker_data import ExampleBrokerData
-from .tradovate_data import TradovateData
-from .schwab_data import SchwabData
+
+from .yahoo_data_polars import YahooDataPolars as YahooData
+
+
+from .polygon_data_polars import PolygonDataPolars as PolygonDataBacktesting
+
 from .bitunix_data import BitunixData
-from .databento_data import DataBentoData
-from .projectx_data import ProjectXData
\ No newline at end of file
+from .ccxt_backtesting_data import CcxtBacktestingData
+from .example_broker_data import ExampleBrokerData
+from .interactive_brokers_rest_data import InteractiveBrokersRESTData
+from .schwab_data import SchwabData
+from .tradovate_data import TradovateData
+
+from .databento_data_polars import DataBentoDataPolars as DataBentoData
+from .projectx_data import ProjectXData
