@@ -1,3 +1,4 @@
+from __future__ import annotations
 import os
 import re
 import sys
@@ -332,6 +333,8 @@ def print_progress_bar(
     cash=None,
     portfolio_value=None,
 ):
+    # Progress bar should ALWAYS show, even with quiet logs
+    # This is the ONLY output users want to see during quiet backtesting
     total_length = end_value - start_value
     current_length = value - start_value
     percent = min((current_length / total_length) * 100, 100)
@@ -534,4 +537,3 @@ def get_timezone_from_datetime(dtm: dt.datetime) -> pytz.timezone:
         return pytz.timezone(timezone_name)
     except (AttributeError, pytz.exceptions.UnknownTimeZoneError):
         return LUMIBOT_DEFAULT_PYTZ
-
