@@ -5,17 +5,17 @@ This module provides the core ProjectX API client and streaming functionality
 integrated into Lumibot's architecture based on the actual working Project X library.
 """
 
-import logging
 import time
-import os
 import warnings
 from datetime import datetime
-from typing import Callable, Optional, Dict, Any, List
+from typing import Callable, Optional, Dict, List
 
 import pandas as pd
 import pytz
 import requests
 
+from lumibot.tools.lumibot_logger import get_logger
+
 # Suppress SSL deprecation warnings from third-party websocket library
 warnings.filterwarnings("ignore", category=DeprecationWarning, module="websocket")
 warnings.filterwarnings("ignore", category=DeprecationWarning, message="ssl.PROTOCOL_TLS is deprecated")
@@ -23,6 +23,8 @@ warnings.filterwarnings("ignore", category=DeprecationWarning, message="websocke
 warnings.filterwarnings("ignore", category=DeprecationWarning, message="websockets.client.connect is deprecated")
 warnings.filterwarnings("ignore", category=DeprecationWarning, message="websockets.client.WebSocketClientProtocol is deprecated")
 
+logger = get_logger(__name__)
+
 # SignalR imports - will be imported when needed
 try:
     from signalrcore.hub_connection_builder import HubConnectionBuilder
@@ -66,17 +68,17 @@ class ProjectXAuth:
             auth_resp = response.json()
             
         except requests.exceptions.RequestException as e:
-            logging.error(f"Request error: {e}")
+            logger.error(f"Request error: {e}")
             return None
         except ValueError as e:
-            logging.error(f"JSON decode error: {e}")
+            logger.error(f"JSON decode error: {e}")
             return None
         
         # Return None if authentication failed
         if not auth_resp.get("success"):
             error_code = auth_resp.get("errorCode")
             error_message = auth_resp.get("errorMessage", "No error message provided")
-            logging.error(f"Authentication failed - Error Code: {error_code}, Message: {error_message}")
+            logger.error(f"Authentication failed - Error Code: {error_code}, Message: {error_message}")
             return None
         
         return auth_resp.get("token")
@@ -117,7 +119,7 @@ class ProjectXStreaming:
         self.on_trade_update: Optional[Callable] = None
         
         # Setup logging
-        self.logger = logging.getLogger(f"ProjectXStreaming_{self.firm}")
+        self.logger = get_logger(f"ProjectXStreaming_{self.firm}")
     
     def start_user_hub(self) -> bool:
         """Start the user hub connection"""
@@ -273,7 +275,7 @@ class ProjectX:
             "Content-Type": "application/json"
         }
         
-        self.logger = logging.getLogger(f"ProjectXClient_{self.firm}")
+        self.logger = get_logger(f"ProjectXClient_{self.firm}")
     
     def get_streaming_client(self, account_id: int = None) -> ProjectXStreaming:
         """Get streaming client instance"""
@@ -392,40 +394,89 @@ class ProjectX:
         """Place an order for a contract"""
         url = f"{self.base_url}api/order/place"
         
-        payload = {
+        # --- Sanitize & normalize inputs ---
+        try:
+            size_int = int(size)
+        except (TypeError, ValueError):
+            self.logger.warning(f"⚠️ Invalid size '{size}' - defaulting to 1")
+            size_int = 1
+
+        # Remove None values to avoid API model binding issues
+        def _clean(d: dict) -> dict:
+            return {k: v for k, v in d.items() if v is not None}
+
+        base_payload = _clean({
             "accountId": account_id,
             "contractId": contract_id,
             "type": type,
             "side": side,
-            "size": size,
+            "size": size_int,
             "limitPrice": limit_price,
             "stopPrice": stop_price,
             "trailPrice": trail_price,
             "customTag": custom_tag,
             "linkedOrderId": linked_order_id,
-        }
-        
+        })
+
+        # Log the outgoing request (compact)
+        self.logger.debug(f"ProjectX.order_place payload: {base_payload}")
+
+        def _post(json_payload):
+            return requests.post(url, headers=self.headers, json=json_payload, timeout=10)
+
         try:
-            response = requests.post(url, headers=self.headers, json=payload)
-            return response.json()
+            response = _post(base_payload)
+            try:
+                data = response.json()
+            except ValueError:
+                data = {"success": False, "error": f"Non-JSON response {response.status_code}"}
+
+            # Fast path success
+            if response.status_code == 200 and data.get("success"):
+                return data
+
+            # Detect validation pattern requiring wrapper {"request": {...}}
+            errors = (data or {}).get("errors") or {}
+            needs_wrapper = False
+            if isinstance(errors, dict):
+                if "request" in errors or any("The request field is required" in err for err_list in errors.values() for err in (err_list if isinstance(err_list, list) else [err_list])):
+                    needs_wrapper = True
+            # Also if size conversion failed, we retry after forcing int already and potentially wrapping
+            size_error = any("$.size" in err for err_list in errors.values() for err in (err_list if isinstance(err_list, list) else [err_list])) if errors else False
+            
+            if needs_wrapper or size_error:
+                wrapped_payload = {"request": base_payload}
+                self.logger.info("Retrying order_place with wrapped 'request' payload structure")
+                retry_resp = _post(wrapped_payload)
+                try:
+                    retry_data = retry_resp.json()
+                except ValueError:
+                    retry_data = {"success": False, "error": f"Non-JSON response {retry_resp.status_code}"}
+                if retry_resp.status_code == 200 and retry_data.get("success"):
+                    return retry_data
+                # Merge error context
+                return {"success": False, "error": retry_data.get("error") or retry_data, "first_attempt": data}
+
+            # If no specific wrapper need detected just return original data
+            return data if data else {"success": False, "error": f"HTTP {response.status_code}"}
+
         except requests.exceptions.RequestException as e:
-            self.logger.error(f"Error: {e}")
+            self.logger.error(f"Error placing order: {e}")
             return {"success": False, "error": str(e)}
     
     def order_cancel(self, account_id: int, order_id: int) -> dict:
         """Cancel an order"""
         url = f"{self.base_url}api/order/cancel"
-        
-        payload = {
-            "accountId": account_id,
-            "orderId": order_id,
-        }
-        
+        payload = {"accountId": account_id, "orderId": order_id}
         try:
-            response = requests.post(url, headers=self.headers, json=payload)
-            return response.json()
+            response = requests.post(url, headers=self.headers, json=payload, timeout=10)
+            try:
+                data = response.json()
+            except ValueError:
+                data = {"success": False, "error": f"Non-JSON response {response.status_code}"}
+            return data
         except requests.exceptions.RequestException as e:
-            self.logger.error(f"Error: {e}")
+            self.logger.error(f"Error cancelling order: {e}")
             return {"success": False, "error": str(e)}
     
     def contract_search(self, search_text: str, live: bool = False) -> dict:
@@ -583,7 +634,7 @@ class ProjectXClient:
         self.firm = config.get("firm")
         
         # Setup logging
-        self.logger = logging.getLogger(f"ProjectXClient_{self.firm}")
+        self.logger = get_logger(f"ProjectXClient_{self.firm}")
         
         # Get authentication token
         self.token = ProjectXAuth.get_auth_token(config)
@@ -626,28 +677,36 @@ class ProjectXClient:
             raise Exception(f"Failed to retrieve accounts: {response}")
     
     def get_preferred_account_id(self) -> int:
-        """Get preferred account ID"""
+        """Get preferred account ID - use configured preferred account or highest balance"""
         accounts = self.get_accounts()
         
-        # Filter for practice accounts
-        practice_accounts = [
-            account for account in accounts
-            if account.get("name", "").lower().startswith(("prac", "tof-px"))
-        ]
+        if not accounts:
+            raise Exception("No accounts found")
         
-        if not practice_accounts:
-            raise Exception("No practice accounts found")
+        self.logger.debug(f"Found {len(accounts)} accounts: {[acc.get('name', 'Unknown') for acc in accounts]}")
         
-        # Use preferred account if specified
+        # First priority: Use specifically configured preferred account name
         preferred_name = self.config.get("preferred_account_name")
         if preferred_name:
-            for account in practice_accounts:
+            self.logger.info(f"Looking for preferred account: {preferred_name}")
+            for account in accounts:
                 if account.get('name') == preferred_name:
-                    return account.get('id')
+                    account_id = account.get('id')
+                    account_balance = account.get('balance', 0)
+                    self.logger.info(f"✅ Using preferred account: {preferred_name} (ID: {account_id}, Balance: ${account_balance:,.2f})")
+                    return account_id
+            
+            # If preferred account not found, log warning but continue
+            self.logger.warning(f"⚠️ Preferred account '{preferred_name}' not found, using highest balance account")
         
-        # Fallback to highest balance account
-        selected_account = max(practice_accounts, key=lambda x: x.get('balance', 0))
-        return selected_account.get('id')
+        # Fallback: Select account with highest balance
+        selected_account = max(accounts, key=lambda x: x.get('balance', 0))
+        account_id = selected_account.get('id')
+        account_name = selected_account.get('name', 'Unknown')
+        account_balance = selected_account.get('balance', 0)
+        
+        self.logger.info(f"✅ Selected highest balance account: {account_name} (ID: {account_id}, Balance: ${account_balance:,.2f})")
+        return account_id
     
     def get_account_balance(self, account_id: int) -> Dict:
         """Get account balance and details"""
@@ -949,9 +1008,9 @@ class ProjectXClient:
                 self.logger.error(f"❌ API search failed: {search_e}")
             
             # If all else fails, return the hardcoded mapping anyway (might work for orders)
-            if symbol_upper in common_futures:
-                fallback_contract = common_futures[symbol_upper]
-                self.logger.info(f"🔄 Fallback to hardcoded mapping: {fallback_contract}")
+            if symbol_upper in common_futures_fallback:
+                fallback_contract = common_futures_fallback[symbol_upper]
+                self.logger.info(f"🔄 Fallback to hardcoded mapping (last resort): {fallback_contract}")
                 return fallback_contract
             
             self.logger.error(f"❌ No contract found for symbol: {symbol}")
@@ -994,6 +1053,13 @@ class ProjectXClient:
         return round(price / tick_size) * tick_size
     
     def order_cancel(self, account_id: int, order_id: int) -> dict:
-        """Cancel an order"""
-        response = self.api.order_cancel(account_id, order_id)
-        return response and response.get("success", False) 
\ No newline at end of file
+        """Cancel an order via high-level client; always return dict."""
+        try:
+            response = self.api.order_cancel(account_id, order_id)
+            # Underlying api.order_cancel returns dict (or False); normalize
+            if isinstance(response, dict):
+                return response
+            return {"success": bool(response)}
+        except Exception as e:
+            self.logger.error(f"Error in order_cancel wrapper: {e}")
+            return {"success": False, "error": str(e)}
